# rots-py

Python implementation of the Reproducibility-Optimized Test Statistic (ROTS) analysis for gene ranking from the [Bioconductor ROTS](https://www.bioconductor.org/packages/release/bioc/html/ROTS.html) package

# Installation 
```
pip install rots-py
```

